@@ -15,7 +15,6 @@ import (
 	// openshift
 	configv1 "github.com/openshift/api/config/v1"
 	oauthv1 "github.com/openshift/api/oauth/v1"
-	operatorsv1 "github.com/openshift/api/operator/v1"
 	operatorv1 "github.com/openshift/api/operator/v1"
 	routev1 "github.com/openshift/api/route/v1"
 	"github.com/openshift/console-operator/pkg/api"
@@ -26,7 +25,6 @@ import (
 	"github.com/openshift/library-go/pkg/operator/resourcesynccontroller"
 
 	// operator
-
 	customerrors "github.com/openshift/console-operator/pkg/console/errors"
 	"github.com/openshift/console-operator/pkg/console/metrics"
 	"github.com/openshift/console-operator/pkg/console/status"
@@ -44,79 +42,96 @@ import (
 // the loop.
 func (co *consoleOperator) sync_v400(updatedOperatorConfig *operatorv1.Console, set configSet) error {
 	klog.V(4).Infoln("running sync loop 4.0.0")
+	statusHandler := status.NewStatusHandler(co.operatorClient)
 
 	// track changes, may trigger ripples & update operator config or console config status
 	toUpdate := false
 
-	rt, rtChanged, rtErrReason, rtErr := co.SyncRoute(set.Operator)
-	toUpdate = toUpdate || rtChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "RouteSync", rtErrReason, rtErr)
-	if rtErr != nil {
-		return rtErr
+	routeName := api.OpenShiftConsoleName
+	if routesub.IsCustomRouteSet(updatedOperatorConfig) {
+		routeName = api.OpenshiftConsoleCustomRouteName
 	}
 
-	cm, cmChanged, cmErrReason, cmErr := co.SyncConfigMap(set.Operator, set.Console, set.Infrastructure, rt)
+	route, routeErr := co.routeClient.Routes(api.TargetNamespace).Get(co.ctx, routeName, metav1.GetOptions{})
+	// TODO: this controller is no longer responsible for syncing the route.
+	//   however, the route is essential for several of the components below.
+	//   - is it appropraite for SyncLoopRefresh InProgress to be used here?
+	//     the loop should exit early and wait until the RouteSyncController creates the route.
+	//     there is nothing new in this flow, other than 2 controllers now look
+	//     at the same resource.
+	//     - RouteSyncController is responsible for updates
+	//     - ConsoleOperatorController (future ConsoleDeploymentController) is responsible for reads only.
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("SyncLoopRefresh", "InProgress", routeErr))
+	if routeErr != nil {
+		return statusHandler.FlushAndReturn(routeErr)
+	}
+
+	cm, cmChanged, cmErrReason, cmErr := co.SyncConfigMap(set.Operator, set.Console, set.Infrastructure, route)
 	toUpdate = toUpdate || cmChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "ConfigMapSync", cmErrReason, cmErr)
-	if cmErr != nil {
-		return cmErr
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("ConfigMapSync", cmErrReason, cmErr))
+	if routeErr != nil {
+		return statusHandler.FlushAndReturn(routeErr)
 	}
 
 	serviceCAConfigMap, serviceCAChanged, serviceCAErrReason, serviceCAErr := co.SyncServiceCAConfigMap(set.Operator)
 	toUpdate = toUpdate || serviceCAChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "ServiceCASync", serviceCAErrReason, serviceCAErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("ServiceCASync", serviceCAErrReason, serviceCAErr))
 	if serviceCAErr != nil {
-		return serviceCAErr
+		return statusHandler.FlushAndReturn(serviceCAErr)
 	}
 
 	trustedCAConfigMap, trustedCAConfigMapChanged, trustedCAErrReason, trustedCAErr := co.SyncTrustedCAConfigMap(set.Operator)
 	toUpdate = toUpdate || trustedCAConfigMapChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "TrustedCASync", trustedCAErrReason, trustedCAErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("TrustedCASync", trustedCAErrReason, trustedCAErr))
 	if trustedCAErr != nil {
-		return trustedCAErr
+		return statusHandler.FlushAndReturn(trustedCAErr)
 	}
 
 	// TODO: why is this missing a toUpdate change?
 	customLogoCanMount, customLogoErrReason, customLogoError := co.SyncCustomLogoConfigMap(updatedOperatorConfig)
 	// If the custom logo sync fails for any reason, we are degraded, not progressing.
 	// The sync loop may not settle, we are unable to honor it in current state.
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "CustomLogoSync", customLogoErrReason, customLogoError)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("CustomLogoSync", customLogoErrReason, customLogoError))
+	if customLogoError != nil {
+		return statusHandler.FlushAndReturn(customLogoError)
+	}
 
 	defaultIngressCertConfigMap, defaultIngressCertErrReason, defaultIngressCertErr := co.ValidateDefaultIngressCertConfigMap()
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "DefaultIngressCertValidation", defaultIngressCertErrReason, defaultIngressCertErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("DefaultIngressCertValidation", defaultIngressCertErrReason, defaultIngressCertErr))
 	if defaultIngressCertErr != nil {
-		return defaultIngressCertErr
+		return statusHandler.FlushAndReturn(defaultIngressCertErr)
 	}
 
 	sec, secChanged, secErr := co.SyncSecret(set.Operator)
 	toUpdate = toUpdate || secChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "OAuthClientSecretSync", "FailedApply", secErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("OAuthClientSecretSync", "FailedApply", secErr))
 	if secErr != nil {
-		return secErr
+		return statusHandler.FlushAndReturn(secErr)
 	}
 
-	oauthClient, oauthChanged, oauthErrReason, oauthErr := co.SyncOAuthClient(set.Operator, sec, rt)
+	oauthClient, oauthChanged, oauthErrReason, oauthErr := co.SyncOAuthClient(set.Operator, sec, route)
 	toUpdate = toUpdate || oauthChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "OAuthClientSync", oauthErrReason, oauthErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("OAuthClientSync", oauthErrReason, oauthErr))
 	if oauthErr != nil {
-		return oauthErr
+		return statusHandler.FlushAndReturn(oauthErr)
 	}
 
-	actualDeployment, depChanged, depErrReason, depErr := co.SyncDeployment(set.Operator, cm, serviceCAConfigMap, defaultIngressCertConfigMap, trustedCAConfigMap, sec, rt, set.Proxy, customLogoCanMount)
+	actualDeployment, depChanged, depErrReason, depErr := co.SyncDeployment(set.Operator, cm, serviceCAConfigMap, defaultIngressCertConfigMap, trustedCAConfigMap, sec, set.Proxy, customLogoCanMount)
 	toUpdate = toUpdate || depChanged
-	status.HandleProgressingOrDegraded(updatedOperatorConfig, "DeploymentSync", depErrReason, depErr)
+	statusHandler.AddConditions(status.HandleProgressingOrDegraded("DeploymentSync", depErrReason, depErr))
 	if depErr != nil {
-		return depErr
+		return statusHandler.FlushAndReturn(depErr)
 	}
 
-	resourcemerge.SetDeploymentGeneration(&updatedOperatorConfig.Status.Generations, actualDeployment)
-	updatedOperatorConfig.Status.ObservedGeneration = set.Operator.ObjectMeta.Generation
+	statusHandler.UpdateDeploymentGeneration(actualDeployment)
+	statusHandler.UpdateReadyReplicas(actualDeployment.Status.ReadyReplicas)
+	statusHandler.UpdateObservedGeneration(set.Operator.ObjectMeta.Generation)
 
 	klog.V(4).Infoln("-----------------------")
 	klog.V(4).Infof("sync loop 4.0.0 resources updated: %v", toUpdate)
 	klog.V(4).Infoln("-----------------------")
 
-	status.HandleProgressing(updatedOperatorConfig, "SyncLoopRefresh", "InProgress", func() error {
+	statusHandler.AddCondition(status.HandleProgressing("SyncLoopRefresh", "InProgress", func() error {
 		if toUpdate {
 			return errors.New("Changes made during sync updates, additional sync expected.")
 		}
@@ -128,53 +143,40 @@ func (co *consoleOperator) sync_v400(updatedOperatorConfig *operatorv1.Console,
 			co.versionGetter.SetVersion("operator", version)
 		}
 		return nil
-	}())
+	}()))
 
-	status.HandleAvailable(func() (conf *operatorv1.Console, prefix string, reason string, err error) {
+	statusHandler.AddCondition(status.HandleAvailable(func() (prefix string, reason string, err error) {
 		prefix = "Deployment"
 		if !deploymentsub.IsReady(actualDeployment) {
-			return updatedOperatorConfig, prefix, "InsufficientReplicas", errors.New(fmt.Sprintf("%v pods available for console deployment", actualDeployment.Status.ReadyReplicas))
+			return prefix, "InsufficientReplicas", errors.New(fmt.Sprintf("%v pods available for console deployment", actualDeployment.Status.ReadyReplicas))
 		}
 		if !deploymentsub.IsReadyAndUpdated(actualDeployment) {
-			return updatedOperatorConfig, prefix, "FailedUpdate", errors.New(fmt.Sprintf("%v replicas ready at version %s", actualDeployment.Status.ReadyReplicas, os.Getenv("RELEASE_VERSION")))
+			return prefix, "FailedUpdate", errors.New(fmt.Sprintf("%v replicas ready at version %s", actualDeployment.Status.ReadyReplicas, os.Getenv("RELEASE_VERSION")))
 		}
-		return updatedOperatorConfig, prefix, "", nil
-	}())
-
-	status.HandleAvailable(updatedOperatorConfig, "Route", "FailedAdmittedIngress", func() error {
-		if !routesub.IsAdmitted(rt) {
-			return errors.New("console route is not admitted")
-		}
-		return nil
-	}())
+		return prefix, "", nil
+	}()))
 
 	// if we survive the gauntlet, we need to update the console config with the
 	// public hostname so that the world can know the console is ready to roll
 	klog.V(4).Infoln("sync_v400: updating console status")
-	consoleURL := getConsoleURL(rt)
-
-	if consoleURL == "" {
-		err := customerrors.NewSyncError("waiting on route host")
-		klog.Errorf("%q: %v", "route", err)
-		return err
+	consoleURL, err := getConsoleURL(route)
+	if err != nil {
+		return statusHandler.FlushAndReturn(err)
 	}
 
 	if _, err := co.SyncConsoleConfig(set.Console, consoleURL); err != nil {
 		klog.Errorf("could not update console config status: %v", err)
-		return err
+		return statusHandler.FlushAndReturn(err)
 	}
 
 	if _, _, err := co.SyncConsolePublicConfig(consoleURL); err != nil {
 		klog.Errorf("could not update public console config status: %v", err)
-		return err
+		return statusHandler.FlushAndReturn(err)
 	}
 
 	defer func() {
 		klog.V(4).Infof("sync loop 4.0.0 complete")
 
-		if rtChanged {
-			klog.V(4).Infof("\t route changed: %v", rt.GetResourceVersion())
-		}
 		if cmChanged {
 			klog.V(4).Infof("\t configmap changed: %v", cm.GetResourceVersion())
 		}
@@ -192,7 +194,7 @@ func (co *consoleOperator) sync_v400(updatedOperatorConfig *operatorv1.Console,
 		}
 	}()
 
-	return nil
+	return statusHandler.FlushAndReturn(nil)
 }
 
 func (co *consoleOperator) SyncConsoleConfig(consoleConfig *configv1.Console, consoleURL string) (*configv1.Console, error) {
@@ -203,7 +205,7 @@ func (co *consoleOperator) SyncConsoleConfig(consoleConfig *configv1.Console, co
 		updated.Status.ConsoleURL = consoleURL
 	}
 	metrics.HandleConsoleURL(oldURL, consoleURL)
-	return co.consoleConfigClient.UpdateStatus(updated)
+	return co.consoleConfigClient.UpdateStatus(co.ctx, updated, metav1.UpdateOptions{})
 }
 
 func (co *consoleOperator) SyncConsolePublicConfig(consoleURL string) (*corev1.ConfigMap, bool, error) {
@@ -218,18 +220,17 @@ func (co *consoleOperator) SyncDeployment(
 	defaultIngressCertConfigMap *corev1.ConfigMap,
 	trustedCAConfigMap *corev1.ConfigMap,
 	sec *corev1.Secret,
-	rt *routev1.Route,
 	proxyConfig *configv1.Proxy,
 	canMountCustomLogo bool) (consoleDeployment *appsv1.Deployment, changed bool, reason string, err error) {
 
 	updatedOperatorConfig := operatorConfig.DeepCopy()
-	requiredDeployment := deploymentsub.DefaultDeployment(operatorConfig, cm, serviceCAConfigMap, defaultIngressCertConfigMap, trustedCAConfigMap, sec, rt, proxyConfig, canMountCustomLogo)
+	requiredDeployment := deploymentsub.DefaultDeployment(operatorConfig, cm, serviceCAConfigMap, defaultIngressCertConfigMap, trustedCAConfigMap, sec, proxyConfig, canMountCustomLogo)
 	genChanged := operatorConfig.ObjectMeta.Generation != operatorConfig.Status.ObservedGeneration
 
 	if genChanged {
 		klog.V(4).Infof("deployment generation changed from %d to %d", operatorConfig.ObjectMeta.Generation, operatorConfig.Status.ObservedGeneration)
 	}
-	deploymentsub.LogDeploymentAnnotationChanges(co.deploymentClient, requiredDeployment)
+	deploymentsub.LogDeploymentAnnotationChanges(co.deploymentClient, requiredDeployment, co.ctx)
 
 	deployment, deploymentChanged, applyDepErr := resourceapply.ApplyDeployment(
 		co.deploymentClient,
@@ -247,17 +248,17 @@ func (co *consoleOperator) SyncDeployment(
 // applies changes to the oauthclient
 // should not be called until route & secret dependencies are verified
 func (co *consoleOperator) SyncOAuthClient(operatorConfig *operatorv1.Console, sec *corev1.Secret, rt *routev1.Route) (consoleoauthclient *oauthv1.OAuthClient, changed bool, reason string, err error) {
-	host := routesub.GetCanonicalHost(rt)
-	if host == "" {
-		return nil, false, "FailedHost", customerrors.NewSyncError("waiting on route host")
+	host, routeErr := routesub.GetCanonicalHost(rt)
+	if routeErr != nil {
+		return nil, false, "FailedHost", routeErr
 	}
-	oauthClient, err := co.oauthClient.OAuthClients().Get(oauthsub.Stub().Name, metav1.GetOptions{})
+	oauthClient, err := co.oauthClient.OAuthClients().Get(co.ctx, oauthsub.Stub().Name, metav1.GetOptions{})
 	if err != nil {
 		// at this point we must die & wait for someone to fix the lack of an outhclient. there is nothing we can do.
 		return nil, false, "FailedGet", errors.New(fmt.Sprintf("oauth client for console does not exist and cannot be created (%v)", err))
 	}
 	oauthsub.RegisterConsoleToOAuthClient(oauthClient, host, secretsub.GetSecretString(sec))
-	oauthClient, oauthChanged, oauthErr := oauthsub.CustomApplyOAuth(co.oauthClient, oauthClient)
+	oauthClient, oauthChanged, oauthErr := oauthsub.CustomApplyOAuth(co.oauthClient, oauthClient, co.ctx)
 	if oauthErr != nil {
 		return nil, false, "FailedRegister", oauthErr
 	}
@@ -265,7 +266,7 @@ func (co *consoleOperator) SyncOAuthClient(operatorConfig *operatorv1.Console, s
 }
 
 func (co *consoleOperator) SyncSecret(operatorConfig *operatorv1.Console) (*corev1.Secret, bool, error) {
-	secret, err := co.secretsClient.Secrets(api.TargetNamespace).Get(secretsub.Stub().Name, metav1.GetOptions{})
+	secret, err := co.secretsClient.Secrets(api.TargetNamespace).Get(co.ctx, secretsub.Stub().Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) || secretsub.GetSecretString(secret) == "" {
 		return resourceapply.ApplySecret(co.secretsClient, co.recorder, secretsub.DefaultSecret(operatorConfig, crypto.Random256BitsString()))
 	}
@@ -283,9 +284,9 @@ func (co *consoleOperator) SyncConfigMap(
 	operatorConfig *operatorv1.Console,
 	consoleConfig *configv1.Console,
 	infrastructureConfig *configv1.Infrastructure,
-	consoleRoute *routev1.Route) (consoleConfigMap *corev1.ConfigMap, changed bool, reason string, err error) {
+	activeConsoleRoute *routev1.Route) (consoleConfigMap *corev1.ConfigMap, changed bool, reason string, err error) {
 
-	managedConfig, mcErr := co.configMapClient.ConfigMaps(api.OpenShiftConfigManagedNamespace).Get(api.OpenShiftConsoleConfigMapName, metav1.GetOptions{})
+	managedConfig, mcErr := co.configMapClient.ConfigMaps(api.OpenShiftConfigManagedNamespace).Get(co.ctx, api.OpenShiftConsoleConfigMapName, metav1.GetOptions{})
 	if mcErr != nil && !apierrors.IsNotFound(mcErr) {
 		return nil, false, "FailedGetManagedConfig", mcErr
 	}
@@ -295,17 +296,17 @@ func (co *consoleOperator) SyncConfigMap(
 	// `default-ingress-cert` is only published in `openshift-config-managed` in OpenShift 4.4.0 and newer.
 	// If the `default-ingress-cert` configmap in `openshift-console` exists, we should mount that to the console container,
 	// otherwise default to `/var/run/secrets/kubernetes.io/serviceaccount/ca.crt`
-	_, rcaErr := co.configMapClient.ConfigMaps(api.OpenShiftConsoleNamespace).Get(api.DefaultIngressCertConfigMapName, metav1.GetOptions{})
+	_, rcaErr := co.configMapClient.ConfigMaps(api.OpenShiftConsoleNamespace).Get(co.ctx, api.DefaultIngressCertConfigMapName, metav1.GetOptions{})
 	if rcaErr != nil && apierrors.IsNotFound(rcaErr) {
 		useDefaultCAFile = true
 	}
 
-	monitoringSharedConfig, mscErr := co.configMapClient.ConfigMaps(api.OpenShiftConfigManagedNamespace).Get(api.OpenShiftMonitoringConfigMapName, metav1.GetOptions{})
+	monitoringSharedConfig, mscErr := co.configMapClient.ConfigMaps(api.OpenShiftConfigManagedNamespace).Get(co.ctx, api.OpenShiftMonitoringConfigMapName, metav1.GetOptions{})
 	if mscErr != nil && !apierrors.IsNotFound(mscErr) {
 		return nil, false, "FailedGetMonitoringSharedConfig", mscErr
 	}
 
-	defaultConfigmap, _, err := configmapsub.DefaultConfigMap(operatorConfig, consoleConfig, managedConfig, monitoringSharedConfig, infrastructureConfig, consoleRoute, useDefaultCAFile)
+	defaultConfigmap, _, err := configmapsub.DefaultConfigMap(operatorConfig, consoleConfig, managedConfig, monitoringSharedConfig, infrastructureConfig, activeConsoleRoute, useDefaultCAFile)
 	if err != nil {
 		return nil, false, "FailedConsoleConfigBuilder", err
 	}
@@ -324,9 +325,9 @@ func (co *consoleOperator) SyncConfigMap(
 func (co *consoleOperator) SyncServiceCAConfigMap(operatorConfig *operatorv1.Console) (consoleCM *corev1.ConfigMap, changed bool, reason string, err error) {
 	required := configmapsub.DefaultServiceCAConfigMap(operatorConfig)
 	// we can't use `resourceapply.ApplyConfigMap` since it compares data, and the service serving cert operator injects the data
-	existing, err := co.configMapClient.ConfigMaps(required.Namespace).Get(required.Name, metav1.GetOptions{})
+	existing, err := co.configMapClient.ConfigMaps(required.Namespace).Get(co.ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
-		actual, err := co.configMapClient.ConfigMaps(required.Namespace).Create(required)
+		actual, err := co.configMapClient.ConfigMaps(required.Namespace).Create(co.ctx, required, metav1.CreateOptions{})
 		if err == nil {
 			klog.V(4).Infoln("service-ca configmap created")
 			return actual, true, "", err
@@ -345,7 +346,7 @@ func (co *consoleOperator) SyncServiceCAConfigMap(operatorConfig *operatorv1.Con
 		return existing, false, "", nil
 	}
 
-	actual, err := co.configMapClient.ConfigMaps(required.Namespace).Update(existing)
+	actual, err := co.configMapClient.ConfigMaps(required.Namespace).Update(co.ctx, existing, metav1.UpdateOptions{})
 	if err == nil {
 		klog.V(4).Infoln("service-ca configmap updated")
 		return actual, true, "", err
@@ -356,9 +357,9 @@ func (co *consoleOperator) SyncServiceCAConfigMap(operatorConfig *operatorv1.Con
 
 func (co *consoleOperator) SyncTrustedCAConfigMap(operatorConfig *operatorv1.Console) (trustedCA *corev1.ConfigMap, changed bool, reason string, err error) {
 	required := configmapsub.DefaultTrustedCAConfigMap(operatorConfig)
-	existing, err := co.configMapClient.ConfigMaps(required.Namespace).Get(required.Name, metav1.GetOptions{})
+	existing, err := co.configMapClient.ConfigMaps(required.Namespace).Get(co.ctx, required.Name, metav1.GetOptions{})
 	if apierrors.IsNotFound(err) {
-		actual, err := co.configMapClient.ConfigMaps(required.Namespace).Create(required)
+		actual, err := co.configMapClient.ConfigMaps(required.Namespace).Create(co.ctx, required, metav1.CreateOptions{})
 		if err != nil {
 			return actual, true, "FailedCreate", err
 		}
@@ -376,7 +377,7 @@ func (co *consoleOperator) SyncTrustedCAConfigMap(operatorConfig *operatorv1.Con
 		return existing, false, "", nil
 	}
 
-	actual, err := co.configMapClient.ConfigMaps(required.Namespace).Update(existing)
+	actual, err := co.configMapClient.ConfigMaps(required.Namespace).Update(co.ctx, existing, metav1.UpdateOptions{})
 	if err != nil {
 		return actual, true, "FailedUpdate", err
 	}
@@ -384,52 +385,20 @@ func (co *consoleOperator) SyncTrustedCAConfigMap(operatorConfig *operatorv1.Con
 	return actual, true, "", err
 }
 
-// apply route
-// - be sure to test that we don't trigger an infinite loop by stomping on the
-//   default host name set by the server, or any other values. The ApplyRoute()
-//   logic will have to be sound.
-// - update to ApplyRoute() once the logic is settled
-func (co *consoleOperator) SyncRoute(operatorConfig *operatorv1.Console) (consoleRoute *routev1.Route, isNew bool, reason string, err error) {
-	// ensure we have a route. any error returned is a non-404 error
-	rt, rtIsNew, rtErr := routesub.GetOrCreate(co.routeClient, routesub.DefaultRoute(operatorConfig))
-	if rtErr != nil {
-		return nil, false, "FailedCreate", rtErr
-	}
-
-	// we will not proceed until the route is valid. this eliminates complexity with the
-	// configmap, secret & oauth client as they can be certain they have a host if we pass this point.
-	host := routesub.GetCanonicalHost(rt)
-	if len(host) == 0 {
-		return nil, false, "FailedHost", customerrors.NewSyncError(fmt.Sprintf("route is not available at canonical host %s", rt.Status.Ingress))
-	}
-
-	if validatedRoute, changed := routesub.Validate(rt); changed {
-		// if validation changed the route, issue an update
-		if _, err := co.routeClient.Routes(api.TargetNamespace).Update(validatedRoute); err != nil {
-			// error is unexpected, this is a real error
-			return nil, false, "InvalidRouteCorrection", err
-		}
-		// abort sync, route changed, let it settle & retry
-		return nil, true, "InvalidRoute", customerrors.NewSyncError("route is invalid, correcting route state")
-	}
-	// only return the route if it is valid with a host
-	return rt, rtIsNew, "", rtErr
-}
-
-func (c *consoleOperator) SyncCustomLogoConfigMap(operatorConfig *operatorsv1.Console) (okToMount bool, reason string, err error) {
+func (co *consoleOperator) SyncCustomLogoConfigMap(operatorConfig *operatorv1.Console) (okToMount bool, reason string, err error) {
 	// validate first, to avoid a broken volume mount & a crashlooping console
-	okToMount, reason, err = c.ValidateCustomLogo(operatorConfig)
+	okToMount, reason, err = co.ValidateCustomLogo(operatorConfig)
 
 	if okToMount || configmapsub.IsRemoved(operatorConfig) {
-		if err := c.UpdateCustomLogoSyncSource(operatorConfig); err != nil {
+		if err := co.UpdateCustomLogoSyncSource(operatorConfig); err != nil {
 			return false, "FailedSyncSource", customerrors.NewCustomLogoError("custom logo sync source update error")
 		}
 	}
 	return okToMount, reason, err
 }
 
-func (c *consoleOperator) ValidateDefaultIngressCertConfigMap() (defaultIngressCert *corev1.ConfigMap, reason string, err error) {
-	defaultIngressCertConfigMap, err := c.configMapClient.ConfigMaps(api.OpenShiftConsoleNamespace).Get(api.DefaultIngressCertConfigMapName, metav1.GetOptions{})
+func (co *consoleOperator) ValidateDefaultIngressCertConfigMap() (defaultIngressCert *corev1.ConfigMap, reason string, err error) {
+	defaultIngressCertConfigMap, err := co.configMapClient.ConfigMaps(api.OpenShiftConsoleNamespace).Get(co.ctx, api.DefaultIngressCertConfigMapName, metav1.GetOptions{})
 	if err != nil {
 		klog.V(4).Infoln("default-ingress-cert configmap not found")
 		return nil, "FailedGet", fmt.Errorf("default-ingress-cert configmap not found")
@@ -449,7 +418,7 @@ func (c *consoleOperator) ValidateDefaultIngressCertConfigMap() (defaultIngressC
 // sync loop will run later.  Our operator is waiting to receive
 // the copied configmap into the console namespace for a future
 // sync loop to mount into the console deployment.
-func (c *consoleOperator) UpdateCustomLogoSyncSource(operatorConfig *operatorsv1.Console) error {
+func (c *consoleOperator) UpdateCustomLogoSyncSource(operatorConfig *operatorv1.Console) error {
 	source := resourcesynccontroller.ResourceLocation{}
 	logoConfigMapName := operatorConfig.Spec.Customization.CustomLogoFile.Name
 
@@ -464,7 +433,7 @@ func (c *consoleOperator) UpdateCustomLogoSyncSource(operatorConfig *operatorsv1
 	)
 }
 
-func (c *consoleOperator) ValidateCustomLogo(operatorConfig *operatorsv1.Console) (okToMount bool, reason string, err error) {
+func (co *consoleOperator) ValidateCustomLogo(operatorConfig *operatorv1.Console) (okToMount bool, reason string, err error) {
 	logoConfigMapName := operatorConfig.Spec.Customization.CustomLogoFile.Name
 	logoImageKey := operatorConfig.Spec.Customization.CustomLogoFile.Key
 
@@ -477,7 +446,7 @@ func (c *consoleOperator) ValidateCustomLogo(operatorConfig *operatorsv1.Console
 		klog.V(4).Infoln("no custom logo configured")
 		return false, "", nil
 	}
-	logoConfigMap, err := c.configMapClient.ConfigMaps(api.OpenShiftConfigNamespace).Get(logoConfigMapName, metav1.GetOptions{})
+	logoConfigMap, err := co.configMapClient.ConfigMaps(api.OpenShiftConfigNamespace).Get(co.ctx, logoConfigMapName, metav1.GetOptions{})
 	// If we 404, the logo file may not have been created yet.
 	if err != nil {
 		klog.V(4).Infof("custom logo file %v not found", logoConfigMapName)
@@ -497,18 +466,10 @@ func (c *consoleOperator) ValidateCustomLogo(operatorConfig *operatorsv1.Console
 	return true, "", nil
 }
 
-func getDeploymentGeneration(co *consoleOperator) int64 {
-	deployment, err := co.deploymentClient.Deployments(api.TargetNamespace).Get(deploymentsub.Stub().Name, metav1.GetOptions{})
+func getConsoleURL(route *routev1.Route) (string, error) {
+	host, err := routesub.GetCanonicalHost(route)
 	if err != nil {
-		return -1
+		return "", err
 	}
-	return deployment.Generation
-}
-
-func getConsoleURL(route *routev1.Route) string {
-	host := routesub.GetCanonicalHost(route)
-	if host == "" {
-		return ""
-	}
-	return util.HTTPS(host)
+	return util.HTTPS(host), nil
 }
